@@ -4,6 +4,7 @@
 # app
 from ._autocomplete import make_bash_autocomplete, make_zsh_autocomplete
 from ._converting import attach_deps
+from ._docker import get_docker_container
 from ._dotenv import read_dotenv
 from ._downloads import get_downloads_by_category, get_total_downloads
 from ._editorconfig import make_editorconfig
@@ -12,20 +13,16 @@ from ._git import git_commit, git_tag
 from ._json import make_json
 from ._package import get_package, get_packages, get_resolver
 from ._python import get_python, get_python_env
-from ._roman import arabic2roman, roman2arabic
 from ._shutil import format_size, get_path_size
+from ._transform import transform_imports
 from ._travis import make_travis
 from ._venv import get_venv
-from ._version import bump_file, bump_project, bump_version, get_version_from_file, get_version_from_project
 
 
 __all__ = [
-    'arabic2roman',
     'attach_deps',
-    'bump_file',
-    'bump_project',
-    'bump_version',
     'format_size',
+    'get_docker_container',
     'get_downloads_by_category',
     'get_entrypoints',
     'get_package',
@@ -36,8 +33,6 @@ __all__ = [
     'get_resolver',
     'get_total_downloads',
     'get_venv',
-    'get_version_from_file',
-    'get_version_from_project',
     'git_commit',
     'git_tag',
     'make_bash_autocomplete',
@@ -46,5 +41,5 @@ __all__ = [
     'make_travis',
     'make_zsh_autocomplete',
     'read_dotenv',
-    'roman2arabic',
+    'transform_imports',
 ]
