@@ -18,5 +18,10 @@ class InspectAuthCommand(BaseCommand):
         return parser
 
     def __call__(self) -> bool:
-        print(make_json(data=self.config['auth'], key=self.config.get('filter')))
+        print(make_json(
+            data=self.config['auth'],
+            key=self.config.get('filter'),
+            colors=not self.config['nocolors'],
+            table=self.config['table'],
+        ))
         return True
