@@ -12,15 +12,15 @@ from packaging.version import parse
 from ..cached_property import cached_property
 
 
-@attr.s(hash=False, cmp=True)
+@attr.s(hash=False, eq=False, order=False)
 class Release:
     dependencies = None  # type: tuple
 
-    raw_name = attr.ib(type=str, cmp=False)
-    version = attr.ib(converter=parse, cmp=True)  # typing: ignore
-    time = attr.ib(repr=False, hash=False)                      # upload_time
-    python = attr.ib(default=None, repr=False, cmp=False)       # requires_python
-    hashes = attr.ib(factory=tuple, repr=False, cmp=False)      # digests/sha256
+    raw_name = attr.ib(type=str)
+    version = attr.ib(converter=parse)              # type: ignore
+    time = attr.ib(repr=False)                      # upload_time
+    python = attr.ib(default=None, repr=False)      # requires_python
+    hashes = attr.ib(factory=tuple, repr=False)     # digests/sha256
 
     extra = attr.ib(type=Optional[str], default=None)
 
@@ -47,8 +47,24 @@ class Release:
     def name(self) -> str:
         return canonicalize_name(self.raw_name)
 
+    def __hash__(self) -> int:
+        return hash((self.name, self.version))
+
+    def __eq__(self, other) -> str:
+        if not isinstance(other, type(self)):
+            return NotImplemented
+        if self.name != other.name:
+            return False
+        if self.version != other.version:
+            return False
+        return True
+
+    def __lt__(self, other) -> str:
+        if not isinstance(other, type(self)):
+            return NotImplemented
+        left = (self.name, self.version, self.time)
+        right = (other.name, other.version, other.time)
+        return left < right
+
     def __str__(self):
         return '{name}=={version}'.format(name=self.raw_name, version=self.version)
-
-    def hash(self):
-        return hash((self.name, self.version))
